Index: include/lazy/SkBitmapFactory.h |
diff --git a/include/lazy/SkBitmapFactory.h b/include/lazy/SkBitmapFactory.h |
index e967a915b213186ec47d80bdff38d33be7d4f384..8a39a48a284e1e539b8985f48839cd11823a76ce 100644 |
--- a/include/lazy/SkBitmapFactory.h |
+++ b/include/lazy/SkBitmapFactory.h |
@@ -39,7 +39,7 @@ public: |
/** |
* Signature for a function to decode an image from encoded data. |
*/ |
- typedef bool (*DecodeProc)(const void* data, size_t length, SkImage::Info*, const Target*); |
+ typedef bool (*DecodeProc)(const void* data, size_t length, SkImageInfo*, const Target*); |
/** |
* Create a bitmap factory which uses DecodeProc for decoding. |
@@ -67,18 +67,18 @@ public: |
bool installPixelRef(SkData*, SkBitmap*); |
/** |
* An object for selecting an SkImageCache to use based on an SkImage::Info. |
*/ |
class CacheSelector : public SkRefCnt { |
public: |
SK_DECLARE_INST_COUNT(CacheSelector) |
/** |
* Return an SkImageCache to use based on the provided SkImage::Info. If the caller decides |
* to hang on to the result, it will call ref, so the implementation should not add a ref |
* as a result of this call. |
*/ |
- virtual SkImageCache* selectCache(const SkImage::Info&) = 0; |
+ virtual SkImageCache* selectCache(const SkImageInfo&) = 0; |
private: |
typedef SkRefCnt INHERITED; |
@@ -67,18 +67,18 @@ public: |
bool installPixelRef(SkData*, SkBitmap*); |
/** |
- * An object for selecting an SkImageCache to use based on an SkImage::Info. |
+ * An object for selecting an SkImageCache to use based on an SkImageInfo. |
*/ |
class CacheSelector : public SkRefCnt { |
@@ -67,18 +67,18 @@ public: |
SK_DECLARE_INST_COUNT(CacheSelector) |
/** |
- * Return an SkImageCache to use based on the provided SkImage::Info. If the caller decides |
+ * Return an SkImageCache to use based on the provided SkImageInfo. If the caller decides |
* to hang on to the result, it will call ref, so the implementation should not add a ref |
* as a result of this call. |